@@ -1,18 +1,15 @@
 /*!
 
-A low level, performance oriented parser for
-[EU4](https://en.wikipedia.org/wiki/Europa_Universalis_IV) save files and
-other [PDS](https://www.paradoxplaza.com/) developed titles. Consult [the
-write-up](https://rakaly.com/blog/a-tour-of-pds-clausewitz-syntax) for an in-depth
-look at the Paradox Clausewitz format and the pitfalls that come trying to support
-all variations. It's extremely difficult to write a robust and fast parser for
-this format, but jomini accomplishes both tasks.
+A low level, performance oriented parser for save and game files from [Paradox Development Studio](https://en.wikipedia.org/wiki/Paradox_Development_Studio) titles (eg: Europa Universalis (EU4), Hearts of Iron (HOI4), and Crusader Kings (CK3), Imperator, Stellaris, and Victoria).
 
-Jomini is the cornerstone of [Rakaly](https://rakaly.com/eu4), an EU4
-achievement leaderboard and save file analyzer. This library is also powers
-the [Paradox Game Converters](https://github.com/ParadoxGameConverters) and
-[pdxu](https://github.com/crschnick/pdx_unlimiter) to parse ironman EU4, CK3,
-HOI4, and Imperator saves.
+For an in-depth look at the Paradox Clausewitz format and the pitfalls that come
+trying to support all variations, consult [the write-up](https://pdx.tools/blog/a-tour-of-pds-clausewitz-syntax). In short, it's extremely difficult to write a robust and
+fast parser that abstracts over the format difference between games as well as differences between game patches. Jomini hits the sweet spot between flexibility while still being ergonomic.
+
+Jomini is the cornerstone of the [online EU4 save file
+analyzer](https://pdx.tools). This library also powers the [Paradox Game
+Converters](https://github.com/ParadoxGameConverters) and
+[pdxu](https://github.com/crschnick/pdx_unlimiter).
 
 ## Features
 
@@ -22,7 +19,6 @@ HOI4, and Imperator saves.
 - ✔ Safe: Extensively fuzzed against potential malicious input
 - ✔ Ergonomic: Use [serde](https://serde.rs/derive.html)-like macros to have parsing logic automatically implemented
 - ✔ Embeddable: Cross platform native apps, statically compiled services, or in the browser via [WASM](https://webassembly.org/)
-- ✔ Agnostic: [Parse EU4](https://github.com/rakaly/eu4save), [HOI4](https://github.com/rakaly/hoi4save.git), [Imperator](https://github.com/rakaly/imperator-save), [CK3](https://github.com/rakaly/ck3save), and Vic2 save and game files
 
 ## Quick Start
 
@@ -67,26 +63,52 @@ assert_eq!(actual, expected);
 
 ## Binary Parsing
 
-Parsing data encoded in the binary format is done in a similar fashion but with an extra step.
-Tokens can be encoded into 16 integers, and so one must provide a map from these integers to their
-textual representations
+Parsing data encoded in the binary format is done in a similar fashion but with a couple extra steps for the caller to supply:
+
+- How text should be decoded (typically Windows-1252 or UTF-8)
+- How rational (floating point) numbers are decoded
+- How tokens, which are 16 bit integers that uniquely identify strings, are resolved
+
+Implementors be warned, not only does each Paradox game have a different binary format, but the binary format can vary between patches!
+
+Below is an example that defines a sample binary format and uses a hashmap token lookup.
 
 ```rust
 # #[cfg(feature = "derive")] {
-use jomini::{JominiDeserialize, BinaryDeserializer};
-use std::collections::HashMap;
+use jomini::{BinaryDeserializer, BinaryFlavor, Encoding, JominiDeserialize, Windows1252Encoding};
+use std::{borrow::Cow, collections::HashMap};
 
 #[derive(JominiDeserialize, PartialEq, Debug)]
 struct MyStruct {
     field1: String,
 }
 
+#[derive(Debug, Default)]
+pub struct BinaryTestFlavor;
+
+impl BinaryFlavor for BinaryTestFlavor {
+    fn visit_f32(&self, data: [u8; 4]) -> f32 {
+        f32::from_le_bytes(data)
+    }
+
+    fn visit_f64(&self, data: [u8; 8]) -> f64 {
+        f64::from_le_bytes(data)
+    }
+}
+
+impl Encoding for BinaryTestFlavor {
+    fn decode<'a>(&self, data: &'a [u8]) -> Cow<'a, str> {
+        Windows1252Encoding::decode(data)
+    }
+}
+
 let data = [ 0x82, 0x2d, 0x01, 0x00, 0x0f, 0x00, 0x03, 0x00, 0x45, 0x4e, 0x47 ];
 
 let mut map = HashMap::new();
 map.insert(0x2d82, "field1");
 
-let actual: MyStruct = BinaryDeserializer::from_eu4(&data[..], &map)?;
+let actual: MyStruct = BinaryDeserializer::builder_flavor(BinaryTestFlavor)
+    .from_slice(&data[..], &map)?;
 assert_eq!(actual, MyStruct { field1: "ENG".to_string() });
 # }
 # Ok::<(), Box<dyn std::error::Error>>(())
@@ -105,7 +127,7 @@ Caller is responsible for:
 - Stripping off any header that may be present (eg: `EU4txt` / `EU4bin`)
 - Providing the token resolver for the binary format
 - Providing the conversion to reconcile how, for example, a date may be encoded as an integer in
-the binary format, but as a string when in plaintext.
+  the binary format, but as a string when in plaintext.
 
 ## The Mid-level API
 
