@@ -261,7 +261,9 @@ where
     ///
     /// Unlike the unquoted variant, this method will inspect the data to
     /// ensure everything is properly escaped, like quotes and escape
-    /// characters. And will trim trailing newlines.
+    /// characters. And will trim trailing newlines. The textual data to write
+    /// out is assumed to already be in the correct encoding (windows-1252 or
+    /// UTF-8)
     ///
     /// Also if one tries to write a quoted field as a key this method
     /// will redirect to the unquoted variant
@@ -558,7 +560,7 @@ where
                 TextToken::Parameter(x) => {
                     self.write_preamble()?;
                     write!(self.writer, "[[")?;
-                    self.writer.write_all(x.view_data())?;
+                    self.writer.write_all(x.as_bytes())?;
                     self.writer.write_all(b"]")?;
 
                     if let Ok(obj) = value.read_object() {
@@ -574,7 +576,7 @@ where
                 TextToken::UndefinedParameter(x) => {
                     self.write_preamble()?;
                     write!(self.writer, "[[!")?;
-                    self.writer.write_all(x.view_data())?;
+                    self.writer.write_all(x.as_bytes())?;
                     self.writer.write_all(b"]")?;
 
                     if let Ok(obj) = value.read_object() {
@@ -591,7 +593,7 @@ where
                     // quoted keys really shouldn't happen but when they do
                     // we should make sure to preserve them. This is different
                     // behavior than writing by hand.
-                    self.force_write_quotes(x.view_data())?;
+                    self.force_write_quotes(x.as_bytes())?;
                     if let Some(op) = op {
                         self.write_operator(op)?;
                     }
@@ -599,7 +601,7 @@ where
                     self.write_value(value)?;
                 }
                 _ => {
-                    self.write_unquoted(key.read_scalar().view_data())?;
+                    self.write_unquoted(key.read_scalar().as_bytes())?;
                     if let Some(op) = op {
                         self.write_operator(op)?;
                     }
@@ -636,10 +638,10 @@ where
                 self.write_object_core(obj)?;
             }
             TextToken::Unquoted(x) => {
-                self.write_unquoted(x.view_data())?;
+                self.write_unquoted(x.as_bytes())?;
             }
             TextToken::Quoted(x) => {
-                self.force_write_quotes(x.view_data())?;
+                self.force_write_quotes(x.as_bytes())?;
             }
             TextToken::Parameter(_) => unreachable!(),
             TextToken::UndefinedParameter(_) => unreachable!(),
@@ -647,7 +649,7 @@ where
             TextToken::End(_) => unreachable!(),
             TextToken::Header(x) => {
                 let mut arr = value.read_array().unwrap();
-                self.write_header(x.view_data())?;
+                self.write_header(x.as_bytes())?;
                 arr.next_value().unwrap();
                 let elem = arr.next_value().unwrap();
                 self.write_value(elem)?;
@@ -782,6 +784,9 @@ fn escape(data: &[u8], mut buffer: Vec<u8>) -> ReuseVec {
 
             if let Some(&last) = data.last() {
                 if last != b'\n' {
+                    if last == b'\\' || last == b'"' {
+                        buffer.push(b'\\');
+                    }
                     buffer.push(last);
                 }
             }
@@ -803,8 +808,8 @@ fn escape(data: &[u8], mut buffer: Vec<u8>) -> ReuseVec {
 
 #[cfg(test)]
 mod tests {
-    use crate::common::{DateHour, PdsDate};
     use super::*;
+    use crate::common::{DateHour, PdsDate};
     use std::error::Error;
 
     #[test]
@@ -1221,10 +1226,16 @@ mod tests {
         assert_eq!(b"abc"[..], *actual);
         let actual = escape(b"Joe \"Captain\" Rogers\n", actual.buffer());
         assert_eq!(br#"Joe \"Captain\" Rogers"#[..], *actual);
+        let actual = escape(br#"Project "Eagle""#, actual.buffer());
+        assert_eq!(br#"Project \"Eagle\""#[..], *actual);
+        let actual = escape(br#"Project Eagle""#, actual.buffer());
+        assert_eq!(br#"Project Eagle\""#[..], *actual);
+        let actual = escape(br#"\abc\"#, actual.buffer());
+        assert_eq!(br#"\\abc\\"#[..], *actual);
     }
 
     #[test]
-    fn test_date_hour_write()  -> Result<(), Box<dyn Error>> {
+    fn test_date_hour_write() -> Result<(), Box<dyn Error>> {
         let date = DateHour::from_ymdh(1936, 1, 1, 1);
         let date2 = DateHour::from_ymdh(1936, 1, 1, 24);
         let mut out: Vec<u8> = Vec::new();
@@ -1233,7 +1244,10 @@ mod tests {
         writer.write_date(date.game_fmt())?;
         writer.write_unquoted(b"date2")?;
         writer.write_date(date2.game_fmt())?;
-        assert_eq!(std::str::from_utf8(&out).unwrap(), "date=1936.1.1.1\ndate2=1936.1.1.24\n");
+        assert_eq!(
+            std::str::from_utf8(&out).unwrap(),
+            "date=1936.1.1.1\ndate2=1936.1.1.24\n"
+        );
         Ok(())
     }
 }
